@@ -74,12 +74,12 @@ pub const STYLE_CONFIG_DARK_DEFAULT: &str = ".poloto { \
 /// Create a simple theme.
 ///
 pub trait SimpleTheme {
-    fn simple_theme(&mut self, a: &mut dyn sfmt::Write) -> std::fmt::Result;
-    fn simple_theme_dark(&mut self, a: &mut dyn sfmt::Write) -> std::fmt::Result;
+    fn simple_theme(&mut self, a: &mut dyn fmt::Write) -> std::fmt::Result;
+    fn simple_theme_dark(&mut self, a: &mut dyn fmt::Write) -> std::fmt::Result;
 }
 
-impl<X: PlotNumContext, Y: PlotNumContext> SimpleTheme for Plotter<'_, X, Y> {
-    fn simple_theme(&mut self, a: &mut dyn sfmt::Write) -> std::fmt::Result {
+impl<X: PlotNum, Y: PlotNum> SimpleTheme for Plotter<'_, X, Y> {
+    fn simple_theme(&mut self, a: &mut dyn fmt::Write) -> std::fmt::Result {
         write!(
             a,
             "{}<style>{}</style>{}{}",
@@ -90,7 +90,7 @@ impl<X: PlotNumContext, Y: PlotNumContext> SimpleTheme for Plotter<'_, X, Y> {
         )
     }
 
-    fn simple_theme_dark(&mut self, a: &mut dyn sfmt::Write) -> std::fmt::Result {
+    fn simple_theme_dark(&mut self, a: &mut dyn fmt::Write) -> std::fmt::Result {
         write!(
             a,
             "{}<style>{}</style>{}{}",
